sequencetools.repeat_sequence_elements_at_indices
=================================================

.. autofunction:: abjad.tools.sequencetools.repeat_sequence_elements_at_indices.repeat_sequence_elements_at_indices
